lexicons\_builder\.scrappers package
====================================

.. automodule:: lexicons_builder.scrappers
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

lexicons\_builder\.scrappers\.scrappers module
----------------------------------------------

.. automodule:: lexicons_builder.scrappers.scrappers
    :members:
    :undoc-members:
    :show-inheritance:


